@@ -44,7 +44,7 @@ extern zend_module_entry yaf_module_entry;
 # define ZEND_ACC_DTOR	0x0
 #endif
 
-#define PHP_YAF_VERSION 					"3.3.5"
+#define PHP_YAF_VERSION 					"3.3.6"
 
 #define YAF_STARTUP_FUNCTION(module)   	ZEND_MINIT_FUNCTION(yaf_##module)
 #define YAF_RINIT_FUNCTION(module)		ZEND_RINIT_FUNCTION(yaf_##module)
@@ -74,7 +74,11 @@ extern zend_module_entry yaf_module_entry;
 #else
 #define YAF_WRITE_HANDLER       zval *
 #define YAF_WHANDLER_RET(zv)    return zv
+#if PHP_VERSION_ID >= 80000
 HashTable *yaf_fake_get_gc(zend_object *zobj, zval **table, int *n);
+#else
+HashTable *yaf_fake_get_gc(zval *zobj, zval **table, int *n);
+#endif
 #endif
 
 #if PHP_VERSION_ID < 80000
@@ -260,6 +264,11 @@ static zend_always_inline uint32_t yaf_compose_2_pathes(char *buf, zend_string *
 }
 #endif
 
+/* removed in 8.3 */
+#ifndef ZEND_HOT
+#define ZEND_HOT
+#endif
+
 /*
  * Local variables:
  * tab-width: 4
