@@ -21,15 +21,6 @@
 #define YAF_ROUTE_ASSEMBLE_ACTION_FORMAT ":a"
 #define YAF_ROUTE_ASSEMBLE_CONTROLLER_FORMAT ":c"
 
-YAF_BEGIN_ARG_INFO_EX(yaf_route_route_arginfo, 0, 0, 1)
-	YAF_ARG_INFO(0, request)
-YAF_END_ARG_INFO()
-
-YAF_BEGIN_ARG_INFO_EX(yaf_route_assemble_arginfo, 0, 0, 1)
-	YAF_ARG_ARRAY_INFO(0, info, 0)
-	YAF_ARG_ARRAY_INFO(0, query, 1)
-YAF_END_ARG_INFO()
-
 extern zend_class_entry *yaf_route_ce;
 
 int yaf_route_instance(yaf_route_t *route, HashTable *config);
