@@ -72,7 +72,11 @@ void yaf_iterator_dtor(zend_object_iterator *iter) /* {{{ */ {
 /* }}} */
 
 #if PHP_VERSION_ID >= 70400
+#if PHP_VERSION_ID >= 80000
 HashTable *yaf_fake_get_gc(zend_object *zobj, zval **table, int *n) /* {{{ */ {
+#else
+HashTable *yaf_fake_get_gc(zval *zobj, zval **table, int *n) /* {{{ */ {
+#endif
 	*n = 0;
 	*table = NULL;
 	return NULL;
