@@ -30,13 +30,13 @@
 #include "yaf_controller.h"
 #include "yaf_action.h"
 
-zend_class_entry *yaf_action_ce;
+#if PHP_MAJOR_VERSION > 7
+#include "yaf_controller_arginfo.h"
+#else
+#include "yaf_controller_legacy_arginfo.h"
+#endif
 
-/** {{{ ARG_INFO
- */
-ZEND_BEGIN_ARG_INFO_EX(yaf_action_void_arginfo, 0, 0, 0)
-ZEND_END_ARG_INFO()
-/* }}} */
+zend_class_entry *yaf_action_ce;
 
 void yaf_action_init(yaf_action_object *action, yaf_controller_t *ctl, zend_string *name) /* {{{ */ {
 	ZVAL_COPY(&action->ctl.ctl, ctl);
@@ -81,10 +81,10 @@ PHP_METHOD(yaf_action, getControllerName) {
 /** {{{ yaf_controller_methods
 */
 zend_function_entry yaf_action_methods[] = {
-	PHP_ABSTRACT_ME(yaf_action_controller, execute, yaf_action_void_arginfo)
-	PHP_ME(yaf_action, getController, yaf_action_void_arginfo, ZEND_ACC_PUBLIC)
-	PHP_ME(yaf_action, getControllerName, yaf_action_void_arginfo, ZEND_ACC_PUBLIC)
-	{NULL, NULL, NULL}
+    PHP_ABSTRACT_ME(yaf_action_controller, execute, arginfo_class_Yaf_Action_Abstract_execute)
+    PHP_ME(yaf_action, getController, arginfo_class_Yaf_Action_Abstract_getController, ZEND_ACC_PUBLIC)
+    PHP_ME(yaf_action, getControllerName, arginfo_class_Yaf_Action_Abstract_getControllerName, ZEND_ACC_PUBLIC)
+    {NULL, NULL, NULL}
 };
 /* }}} */
 
